import requests_toolbelt.sessions

session = requests_toolbelt.sessions.BaseUrlSession(base_url="http://localhost:10001")

post = session.post
delete = session.delete
get = session.get
put = session.put
patch = session.patch
head = session.head
options = session.options



from setuptools import setup, find_packages

setup(
    name="backend-bridge",
    version="1.0.0",
    packages=find_packages(),
    install_requires=["requests-toolbelt"],
    description="注册并代理转发后端服务",
)
